tinymce.addI18n('id',{
"Cut": "Penggal",
"Header 2": "Header 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Browser anda tidak mendukung akses langsung ke clipboard. Silahkan gunakan Ctrl+X\/C\/V dari keyboard.",
"Div": "Div",
"Paste": "Tempel",
"Close": "Tutup",
"Pre": "Pre",
"Align right": "Rata kanan",
"New document": "Dokumen baru",
"Blockquote": "Kutipan",
"Numbered list": "list nomor",
"Increase indent": "Tambah inden",
"Formats": "Format",
"Headers": "Header",
"Select all": "Pilih semua",
"Header 3": "Header 3",
"Blocks": "Blok",
"Undo": "Batal",
"Strikethrough": "Coret",
"Bullet list": "list simbol",
"Header 1": "Header 1",
"Superscript": "Superskrip",
"Clear formatting": "Hapus format",
"Subscript": "Subskrip",
"Header 6": "Header 6",
"Redo": "Ulang",
"Paragraph": "Paragraf",
"Ok": "Ok",
"Bold": "Tebal",
"Code": "Code",
"Italic": "Miring",
"Align center": "Rate tengah",
"Header 5": "Header 5",
"Decrease indent": "Turunkan inden",
"Header 4": "Header 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Aksi 'Tempel' sekarang ini dalam mode text. Konten akan 'ditempelkan' sebagai 'Plain Text' hingga anda mematikan opsi ini.",
"Underline": "Garis bawah",
"Cancel": "Batal",
"Justify": "Justifi",
"Inline": "Inline",
"Copy": "Salin",
"Align left": "Rate kiri",
"Visual aids": "Alat bantu visual",
"Lower Greek": "Lower Yunani",
"Square": "Kotak",
"Default": "Bawaan",
"Lower Alpha": "Lower Alpha",
"Circle": "Lingkaran",
"Disc": "Cakram",
"Upper Alpha": "Upper Alpha",
"Upper Roman": "Upper Roman",
"Lower Roman": "Lower Roman",
"Name": "Nama",
"Anchor": "Anjar",
"You have unsaved changes are you sure you want to navigate away?": "Anda memiliki perubahan yang belum disimpan, yakin ingin beralih ?",
"Restore last draft": "Muat kembali draft sebelumnya",
"Special character": "Spesial karakter",
"Source code": "Kode sumber",
"Right to left": "Kanan ke kiri",
"Left to right": "Kiri ke kanan",
"Emoticons": "Emotikon",
"Robots": "Robot",
"Document properties": "Properti dokumwn",
"Title": "Judul",
"Keywords": "Kata kunci",
"Encoding": "Enkoding",
"Description": "Deskripsi",
"Author": "Penulis",
"Fullscreen": "Layar penuh"
});